import { RevertibleIterable } from './revertible-iterable';
/**
 * Builds an iterable over the keys of the given object.
 *
 * A list of keys is constructed using `Reflect.ownKeys()`.
 *
 * @param target  An object to select keys from.
 */
export declare function overKeys<T extends object>(target: T): RevertibleIterable<keyof T>;
/**
 * Object property entry. This is a tuple consisting of property key and value.
 */
export declare type ObjectEntry<T, K extends keyof T = keyof T> = [K, T[K]];
/**
 * Builds an iterable over the key/value entries of the given object.
 *
 * A list of keys is constructed using `Reflect.ownKeys()`.
 *
 * @param target  An object to select keys and values from.
 */
export declare function overEntries<T extends object>(target: T): RevertibleIterable<ObjectEntry<T>>;
//# sourceMappingURL=objects.d.ts.map